==> egroupware-epl_14.1.20150210.orig.tar.gz: egroupware/etemplate/inc/hook_sidebox_menu.inc.php <==
<?php
	/**
	 * eGroupWare - Setup
	 * Originaly from the phpGW XSLT API
	 *
	 * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
	 * @package etemplate
	 * @link http://www.egroupware.org
	 * @author Ralf Becker <RalfBecker@outdoor-training.de>
	 * @version $Id: hook_sidebox_menu.inc.php 46152 2014-03-10 09:10:49Z ralfbecker $
	 */

	$menu_title = $GLOBALS['egw_info']['apps'][$appname]['title'] . ' '. lang('Menu');
	$file = Array(
		'eTemplate Editor' => $GLOBALS['egw']->link('/index.php','menuaction=etemplate.editor.edit'),
		'DB-Tools' => $GLOBALS['egw']->link('/index.php','menuaction=etemplate.db_tools.edit'),
	);
	if (@$GLOBALS['egw_info']['user']['apps']['developer_tools'])
	{
		$file += array(
			'_NewLine_', // give a newline
			'developer_tools' => $GLOBALS['egw']->link('/index.php','menuaction=developer_tools.uilangfile.index'),
		);
	 }
	 if($GLOBALS['egw_info']['flags']['currentapp'] == 'etemplate')
	 {
		display_sidebox($appname,$menu_title,$file);
	 }
	$menu_title = lang('Documentation');
	$docs = $GLOBALS['egw_info']['server']['webserver_url'].'/etemplate/doc/';
	$file = Array(
		array(
			'text'   => 'eTemplate2 Reference',
			'link'   => egw::link('/index.php','menuaction=etemplate.etemplate_et2_widgets.index', 'etemplate'),
		),
		array(
			'text'   => 'eTemplate Tutorial',
			'link'   => $docs.'etemplate.html',
			'target' => 'docs'
		),
		array(
			'text'   => 'eTemplate Reference',
			'link'   => $docs.'reference.html',
			'target' => 'docs'
		),
		array(
			'text'   => 'eGroupWare '.lang('Documentation'),
			'no_lang' => True,
			'link'   => 'http://egroupware.org/wiki/DeveloperDocs',
			'target' => 'docs'
		),
		array(
			'text'   => 'CSS properties',
			'link'   => 'http://www.w3.org/TR/REC-CSS2/propidx.html',
			'target' => 'docs'
		),

	);

	if($GLOBALS['egw_info']['flags']['currentapp'] == 'etemplate')
	{
	   display_sidebox($appname,$menu_title,$file);
	}

==> egroupware-epl_14.3.20160708.orig.tar.gz: egroupware/etemplate/inc/hook_sidebox_menu.inc.php <==
<?php
	/**
	 * eGroupWare - Setup
	 * Originaly from the phpGW XSLT API
	 *
	 * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
	 * @package etemplate
	 * @link http://www.egroupware.org
	 * @author Ralf Becker <RalfBecker@outdoor-training.de>
	 * @version $Id$
	 */

	$menu_title = $GLOBALS['egw_info']['apps'][$appname]['title'] . ' '. lang('Menu');
	$file = Array(
		'eTemplate Editor' => $GLOBALS['egw']->link('/index.php','menuaction=etemplate.editor.edit'),
		'DB-Tools' => $GLOBALS['egw']->link('/index.php','menuaction=etemplate.db_tools.edit'),
		'_NewLine_', // give a newline
		'developer_tools' => $GLOBALS['egw']->link('/index.php','menuaction=etemplate.uilangfile.index'),
	);
	if($GLOBALS['egw_info']['flags']['currentapp'] == 'etemplate')
	{
		display_sidebox($appname,$menu_title,$file);
	}
	$menu_title = lang('Documentation');
	$docs = $GLOBALS['egw_info']['server']['webserver_url'].'/etemplate/doc/';
	$file = Array(
		array(
			'text'   => 'eTemplate2 Reference',
			'link'   => egw::link('/index.php','menuaction=etemplate.etemplate_et2_widgets.index', 'etemplate'),
		),
		array(
			'text'   => 'eTemplate Tutorial',
			'link'   => $docs.'etemplate.html',
			'target' => 'docs'
		),
		array(
			'text'   => 'eTemplate Reference',
			'link'   => $docs.'reference.html',
			'target' => 'docs'
		),
		array(
			'text'   => 'eGroupWare '.lang('Documentation'),
			'no_lang' => True,
			'link'   => 'http://egroupware.org/wiki/DeveloperDocs',
			'target' => 'docs'
		),
		array(
			'text'   => 'CSS properties',
			'link'   => 'http://www.w3.org/TR/REC-CSS2/propidx.html',
			'target' => 'docs'
		),

	);

	if($GLOBALS['egw_info']['flags']['currentapp'] == 'etemplate')
	{
	   display_sidebox($appname,$menu_title,$file);
	}
